change_encryption_flag

Function change_encryption_flag 

fn change_encryption_flag(
    packs: &mut BTreeMap<String, Pack>,
    pack_key: &str,
    flag: PFHFlags,
    state: bool,
    sender: &UnboundedSender<Response>,
)
Sets or clears one of the encryption flags of a pack, sending the result back.

Enabling encryption is rejected on Packs whose version doesn’t support it.