git_update_check

Function git_update_check 

fn git_update_check(
    sender: UnboundedSender<Response>,
    path_fn: fn() -> Result<PathBuf>,
    repo: &'static str,
    branch: &'static str,
    remote: &'static str,
)
Spawns an async task that checks for git updates for the given repository configuration, sending the result back through sender.