plugin_script_interpreter

Function plugin_script_interpreter 

fn plugin_script_interpreter(path: &Path) -> Option<&'static str>
Returns the interpreter command for a plugin script, based on its extension.

Returns None for unsupported extensions, which is also how we filter the scripts folder.