pub fn get_trait_ceos(deps: &Dependencies) -> Vec<(String, String)>Expand description
Fetch all trait CEOs from the Assembly Kit data, resolving display names via loc.
pub fn get_trait_ceos(deps: &Dependencies) -> Vec<(String, String)>Fetch all trait CEOs from the Assembly Kit data, resolving display names via loc.