CentralCommand

Struct CentralCommand 

pub struct CentralCommand<T: Send + Sync + Debug> {
    sender: UnboundedSender<(UnboundedSender<T>, Command)>,
    receiver: Mutex<Option<UnboundedReceiver<(UnboundedSender<T>, Command)>>>,
}
This struct contains the senders and receivers necessary to communicate between both threads.

You can use them by using the send/recv functions implemented for it.

Fields

sender: UnboundedSender<(UnboundedSender<T>, Command)>receiver: Mutex<Option<UnboundedReceiver<(UnboundedSender<T>, Command)>>>

Implementations

Source

impl<T: Send + Sync + Debug> CentralCommand<T>

pub fn send(&self, data: Command) -> UnboundedReceiver<T>

This function serves as a generic way for commands to be sent to the backend.

It returns the receiver which will receive the answers for the command, if any.

pub fn send_back(sender: &UnboundedSender<T>, data: T)

This function serves to send a message back through a generated channel.

pub fn take_receiver( &self, ) -> Option<UnboundedReceiver<(UnboundedSender<T>, Command)>>

This functions serves to take the receiver from the central command.

pub async fn recv(receiver: &mut UnboundedReceiver<T>) -> T

This functions serves to receive messages from a generated channel.

This function does only try once, and it locks the thread. Panics if the response fails.