recv_response

Function recv_response 

pub async fn recv_response(
    receiver: &mut UnboundedReceiver<Response>,
) -> Response
Helper function to receive a response from a session.

This is async and will wait for the response.