default_config_path

Function default_config_path 

pub fn default_config_path() -> Result<PathBuf>
This function returns RPFM’s default config path, ignoring any custom-folder redirect.

Note: On `Debug´ mode this project is the project from where you execute one of RPFM’s programs, which should be the root of the repo.