pub fn scripts_path() -> Result<PathBuf>Expand description
Folder under config_path where the user drops plugin scripts shown in the
PackFile contents context menu.
pub fn scripts_path() -> Result<PathBuf>Folder under config_path where the user drops plugin scripts shown in the
PackFile contents context menu.