pub fn sign_in_start() -> Result<DeviceCode>Expand description
Start a GitHub sign-in with the device flow.
Errors
Returns an error if this build has no GitHub client ID, or the request fails.
pub fn sign_in_start() -> Result<DeviceCode>Start a GitHub sign-in with the device flow.
Returns an error if this build has no GitHub client ID, or the request fails.