UpdateChannel

Enum UpdateChannel 

pub enum UpdateChannel {
    Stable,
    Beta,
}
Channels RPFM can pull updates from.

Versions in the third semver component greater than or equal to 99 are treated as betas (e.g. 4.7.99), versions below 99 as stable. The check logic in check_updates_rpfm_with uses this to allow opting out of betas: a beta user with the stable channel selected will see the most recent stable release as an available “update” even when its version number is lower.

Variants



Stable

Only stable releases are considered.



Beta

Both stable and beta releases are considered, latest first.