check_updates_rpfm

Function check_updates_rpfm 

pub fn check_updates_rpfm(settings: &Settings) -> Result<APIResponse>
This function takes care of checking for new RPFM updates.

Also, this has a special behavior: If we have a beta version and we have the stable channel selected, it’ll pick the newest stable release, even if it’s older than our beta. That way we can easily opt-out of betas.