fn change_encryption_flag(
packs: &mut BTreeMap<String, Pack>,
pack_key: &str,
flag: PFHFlags,
state: bool,
sender: &UnboundedSender<Response>,
)Expand description
Sets or clears one of the encryption flags of a pack, sending the result back.
Enabling encryption is rejected on Packs whose version doesn’t support it.