pub struct CentralCommand<T: Send + Sync + Debug> {
sender: UnboundedSender<(UnboundedSender<T>, Command)>,
receiver: Mutex<Option<UnboundedReceiver<(UnboundedSender<T>, Command)>>>,
}Expand description
This struct contains the senders and receivers necessary to communicate between both threads.
You can use them by using the send/recv functions implemented for it.
Fields
sender: UnboundedSender<(UnboundedSender<T>, Command)>receiver: Mutex<Option<UnboundedReceiver<(UnboundedSender<T>, Command)>>>Implementations
Sourceimpl<T: Send + Sync + Debug> CentralCommand<T>
impl<T: Send + Sync + Debug> CentralCommand<T>
Sourcepub fn send(&self, data: Command) -> UnboundedReceiver<T>
pub fn send(&self, data: Command) -> UnboundedReceiver<T>
This function serves as a generic way for commands to be sent to the backend.
It returns the receiver which will receive the answers for the command, if any.
Sourcepub fn send_back(sender: &UnboundedSender<T>, data: T)
pub fn send_back(sender: &UnboundedSender<T>, data: T)
This function serves to send a message back through a generated channel.
Sourcepub fn take_receiver(
&self,
) -> Option<UnboundedReceiver<(UnboundedSender<T>, Command)>>
pub fn take_receiver( &self, ) -> Option<UnboundedReceiver<(UnboundedSender<T>, Command)>>
This functions serves to take the receiver from the central command.