pub fn config_path() -> Result<PathBuf>Expand description
This function returns the current config path, or an error if said path is not available.
Note: On `Debug´ mode this project is the project from where you execute one of RPFM’s programs, which should be the root of the repo.