fn hub_repository() -> (String, String)Expand description
Owner and name of the repository translations are submitted to.
Debug builds can submit to another repository, set in RPFM_TRANSLATION_HUB as owner/name, to test without touching the real hub.